/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  task_state_statistics: 'Task State Statistics',
  workflow_state_statistics: 'Workflow State Statistics',
  workflow_definition_statistics: 'Workflow Definition Statistics',
  number: 'Number',
  state: 'State',
  submitted_success: 'SUBMITTED_SUCCESS',
  running_execution: 'RUNNING_EXECUTION',
  ready_pause: 'READY_PAUSE',
  pause: 'PAUSE',
  ready_stop: 'READY_STOP',
  stop: 'STOP',
  failure: 'FAILURE',
  success: 'SUCCESS',
  need_fault_tolerance: 'NEED_FAULT_TOLERANCE',
  kill: 'KILL',
  waiting_thread: 'WAITING_THREAD',
  waiting_depend: 'WAITING_DEPEND',
  delay_execution: 'DELAY_EXECUTION',
  forced_success: 'FORCED_SUCCESS',
  serial_wait: 'SERIAL_WAIT',
  dispatch: 'DISPATCH',
  ready_block: 'READY_BLOCK',
  block: 'BLOCK',
  wait_to_run: 'WAIT_TO_RUN',
  failover: 'FAILOVER'
}
